/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_ddr4tpGn);
  numBytes += sLine_init(&sLine_OfGf9hRP);
  numBytes += sLine_init(&sLine_JLPdqsA1);
  numBytes += sLine_init(&sLine_QXz2A6LN);
  numBytes += sLine_init(&sLine_1sVwIh9U);
  numBytes += sBiquad_init(&sBiquad_s_Nrc9u3Lv);
  numBytes += sLine_init(&sLine_k4Hwig4i);
  numBytes += sLine_init(&sLine_uK0r9fs7);
  numBytes += sLine_init(&sLine_JXJoo8d9);
  numBytes += sLine_init(&sLine_Bjx4SWg8);
  numBytes += sBiquad_init(&sBiquad_s_ZaUcHPZ2);
  numBytes += sLine_init(&sLine_6HK1HJXy);
  numBytes += sLine_init(&sLine_jYNUufTo);
  numBytes += sLine_init(&sLine_ioCZoojV);
  numBytes += sLine_init(&sLine_Ty9fEfvo);
  numBytes += sLine_init(&sLine_a56DXbSB);
  numBytes += sBiquad_init(&sBiquad_s_BlZLPTNS);
  numBytes += sLine_init(&sLine_ZM6GHzWL);
  numBytes += sLine_init(&sLine_uwsG7kfd);
  numBytes += sLine_init(&sLine_69IfdjVs);
  numBytes += sLine_init(&sLine_iDOvWLYq);
  numBytes += sLine_init(&sLine_ctdeXdzV);
  numBytes += sBiquad_init(&sBiquad_s_pBPNOceK);
  numBytes += sLine_init(&sLine_gk2Ydlzh);
  numBytes += sLine_init(&sLine_Uwuuf8Bq);
  numBytes += sLine_init(&sLine_ILWAHCbC);
  numBytes += sLine_init(&sLine_gjCMOH9Y);
  numBytes += sBiquad_init(&sBiquad_s_yrOxRkzU);
  numBytes += sLine_init(&sLine_iIktE68K);
  numBytes += sLine_init(&sLine_KM94CC1R);
  numBytes += sLine_init(&sLine_CCFqq9Pj);
  numBytes += sLine_init(&sLine_omhcwdIG);
  numBytes += sLine_init(&sLine_epC4gVaG);
  numBytes += sBiquad_init(&sBiquad_s_BaZCjvEX);
  numBytes += cVar_init_f(&cVar_54KizWyd, 0.0f);
  numBytes += cVar_init_f(&cVar_OQ5EY8s1, 0.0f);
  numBytes += cVar_init_f(&cVar_OQtowliN, 0.0f);
  numBytes += cVar_init_f(&cVar_W2Dg1HGf, 0.0f);
  numBytes += cSlice_init(&cSlice_Xu8uJ4t6, 1, -1);
  numBytes += cVar_init_f(&cVar_m4z3hphF, 1337.0f);
  numBytes += cVar_init_f(&cVar_tjR6pUMU, 0.0f);
  numBytes += cIf_init(&cIf_DTKY6MwB, false);
  numBytes += cIf_init(&cIf_3qEZxC3F, false);
  numBytes += cBinop_init(&cBinop_Ecb9QWfi, 0.0f); // __pow
  numBytes += cIf_init(&cIf_OPihSGBR, false);
  numBytes += cBinop_init(&cBinop_agLfLepr, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ahXPsb2J, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_IOK2yfCZ, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_QXyuS49D, 0.0f);
  numBytes += cIf_init(&cIf_tyxbew7p, false);
  numBytes += cIf_init(&cIf_Lp1SuP4R, false);
  numBytes += cBinop_init(&cBinop_I1ElB2dz, 0.0f); // __pow
  numBytes += cIf_init(&cIf_1KcN34NJ, false);
  numBytes += cBinop_init(&cBinop_UfEUjLDS, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_L2W8hsAr, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_hbkn36El, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_swwO7OhS, 0.0f);
  numBytes += cIf_init(&cIf_QByRUHMr, false);
  numBytes += cIf_init(&cIf_X9gX4Lvc, false);
  numBytes += cBinop_init(&cBinop_39csgyH3, 0.0f); // __pow
  numBytes += cIf_init(&cIf_p2hKPTeT, false);
  numBytes += cBinop_init(&cBinop_92fliXri, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_KpLUD52e, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_F9WwBjjG, -15.0f); // __eq
  numBytes += cIf_init(&cIf_MvyoNL7Q, false);
  numBytes += cSlice_init(&cSlice_QBoxrI6h, 1, -1);
  numBytes += cVar_init_f(&cVar_IZ1EPsb6, 0.0f);
  numBytes += cSlice_init(&cSlice_8Sh8lIsW, 1, -1);
  numBytes += cVar_init_f(&cVar_3oq5VpUG, 0.0f);
  numBytes += cSlice_init(&cSlice_42rlIM2K, 1, -1);
  numBytes += cVar_init_f(&cVar_Uugoil3L, 0.0f);
  numBytes += cSlice_init(&cSlice_DXUe6KXD, 1, -1);
  numBytes += cVar_init_f(&cVar_fOTEKXtn, 0.313f);
  numBytes += cBinop_init(&cBinop_pj0TAy39, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_bJSILkVZ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_yK1MyeK3, 0.0f);
  numBytes += cVar_init_f(&cVar_gAFxfzIG, 1337.0f);
  numBytes += cVar_init_f(&cVar_F4RFNiwP, 0.3f);
  numBytes += cBinop_init(&cBinop_rYa0sdQn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MIxzSIZF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KsbRuz5A, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nfNhN18z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0FtIFOvt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4NmeCpBv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PJmO30jZ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ybgXRBpI, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_0fiOVuvu, 0.0f);
  numBytes += cVar_init_f(&cVar_oqpJ5hHL, 1337.0f);
  numBytes += cVar_init_f(&cVar_Q7f1Ys8F, 0.313f);
  numBytes += cBinop_init(&cBinop_HH2ATJbY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Nu1lxieO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OYxywcac, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LsfZjnX5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_B2etS9CF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Wq9qSDgh, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_f2t7DfkY, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_kCyo4fUb, 0.0f);
  numBytes += cVar_init_f(&cVar_xqkENoxp, 1037.0f);
  numBytes += cVar_init_f(&cVar_waHca9iK, 0.4f);
  numBytes += cBinop_init(&cBinop_c1hSkwjh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IE6dPqGq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gaIMrN46, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_h3Np6wsa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Fefylhc9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gaF94oLh, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_WqU0f0qh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_x8FVbZCt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EK2byhKD, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_CJCZI3RY, 1, -1);
  numBytes += cVar_init_f(&cVar_P3y9nHtD, 1337.0f);
  numBytes += cVar_init_f(&cVar_0DeadKwt, 0.0f);
  numBytes += cIf_init(&cIf_d2CkKtaU, false);
  numBytes += cIf_init(&cIf_LIbQSxVX, false);
  numBytes += cBinop_init(&cBinop_VkaLXkYR, 0.0f); // __pow
  numBytes += cIf_init(&cIf_HAIAwjkF, false);
  numBytes += cBinop_init(&cBinop_SQLCDpEz, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_HuFKAFGZ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_E4rEsvMR, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_sNYAY9mm, 0.0f);
  numBytes += cIf_init(&cIf_Wg6k4E55, false);
  numBytes += cIf_init(&cIf_kzUJ68aU, false);
  numBytes += cBinop_init(&cBinop_0TgZ9Ibs, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ndqlXJz2, false);
  numBytes += cBinop_init(&cBinop_Epal9KWb, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_MDlCoqOy, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_HxY2EGur, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_FJMYpTHG, 0.0f);
  numBytes += cIf_init(&cIf_f4fVaY4C, false);
  numBytes += cIf_init(&cIf_FJ7g93VW, false);
  numBytes += cBinop_init(&cBinop_sQDodJIM, 0.0f); // __pow
  numBytes += cIf_init(&cIf_T2b55Ebl, false);
  numBytes += cBinop_init(&cBinop_UE136kqy, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_AKLThJtU, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_o4zlZqV1, -15.0f); // __eq
  numBytes += cIf_init(&cIf_a36d07XQ, false);
  numBytes += cSlice_init(&cSlice_XqGm2FbS, 1, -1);
  numBytes += cVar_init_f(&cVar_ZObyBh5u, 0.0f);
  numBytes += cSlice_init(&cSlice_gj3AH7PV, 1, -1);
  numBytes += cVar_init_f(&cVar_4R01CzEN, 0.0f);
  numBytes += cSlice_init(&cSlice_sl2m26uN, 1, -1);
  numBytes += cVar_init_f(&cVar_3UzxmPRb, 0.0f);
  numBytes += cSlice_init(&cSlice_grUJrlFn, 1, -1);
  numBytes += cVar_init_f(&cVar_1IwtQE1x, 0.313f);
  numBytes += cBinop_init(&cBinop_1sqDCmoQ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_MCJpQ34q, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_23xjBPFO, 0.0f);
  numBytes += cVar_init_f(&cVar_nb8ypYfH, 1337.0f);
  numBytes += cVar_init_f(&cVar_sKyJInti, 0.3f);
  numBytes += cBinop_init(&cBinop_9x4LWoAz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IU07p8Qv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PoF83vB5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_20aTUjal, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_k2tTksyw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XUyGO3u7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_m1XWPVnI, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_GFjC5c38, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_wlBdiykf, 0.0f);
  numBytes += cVar_init_f(&cVar_HGEEIo3N, 1337.0f);
  numBytes += cVar_init_f(&cVar_reEasnWf, 0.313f);
  numBytes += cBinop_init(&cBinop_HwdJ8yOL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bV05DW61, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_W0kPw9Zf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3olXFeY5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BG6xQQMX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bVeM3xIp, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_IYkXG78J, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_EQMI0sLu, 0.0f);
  numBytes += cVar_init_f(&cVar_dcTUBvML, 1037.0f);
  numBytes += cVar_init_f(&cVar_hV1mLLIF, 0.4f);
  numBytes += cBinop_init(&cBinop_f72KdTIU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_R1gOUZ0t, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0mxfAgCI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qxIjQpuO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ajrchUyw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rqzrgH0K, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_yMW33LKd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_K3REoeJ9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2q0jgeJQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_HF4yiJlp, 5705.6f);
  numBytes += cVar_init_f(&cVar_MLDXgy6u, 313.3f);
  numBytes += cBinop_init(&cBinop_DCoT1Qce, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_XZ40z6Vm, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_fdMkmWTc, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TDQylHje_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fYGtwueS_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zluhRfkU_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WSJSJyPZ_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dvLWISwn_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hlDnesvV_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nIaxJGIt_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EWsmfZtb_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZNXlcsno_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AqAm1xSG_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RZX1LvxC_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jwV76A7C_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aFrtGlL0_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cWe5nbcU_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DoHBD7yY_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_D02ji0Hy_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mGuNJJd8_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hDehFXnc_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kNJZrHXo_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JA4lJ6LI_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0s3N0Qfc_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KSgmohsg_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3GkujMSm_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7q1OYDUE_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dMlkV7ju_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8DZIMJP1_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iSYoLLns_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tXz3gF2J_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wsaqC5pZ_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HvfnnCOc_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zYybn6QO_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OpZFe3XX_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TJFdHzim_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_54KizWyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QIRXp5jO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_OQ5EY8s1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m9aNVENT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_OQtowliN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_szII0RJh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_W2Dg1HGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vXCpXctX_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AaWE2AJB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CzSd0gVL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1xs8rEVR_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_zkGpOpea_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Xu8uJ4t6, 0, m, &cSlice_Xu8uJ4t6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_27A91zQO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_Xu8uJ4t6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3nMXtGhd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3nMXtGhd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_m4z3hphF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3nMXtGhd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_3nMXtGhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nIaxJGIt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_tjR6pUMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wughi7B3_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_DTKY6MwB, 0, m, &cIf_DTKY6MwB_sendMessage);
}

void Heavy_WSTD_3Q::cIf_DTKY6MwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_enfSzgoz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_3qEZxC3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_VRgWjojK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Efk9uuyn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_FcrmkHh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ecb9QWfi, HV_BINOP_POW, 0, m, &cBinop_Ecb9QWfi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ecb9QWfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OPihSGBR, 0, m, &cIf_OPihSGBR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OVnhu7zG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_EfkNkgew_sendMessage);
}

void Heavy_WSTD_3Q::cCast_EcByMtJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_PVikSslI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_sg9KFJUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3qEZxC3F, 0, m, &cIf_3qEZxC3F_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PVikSslI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3qEZxC3F, 1, m, &cIf_3qEZxC3F_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Efk9uuyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_OVnhu7zG_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_VRgWjojK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_OPihSGBR, 0, m, &cIf_OPihSGBR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EfkNkgew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ecb9QWfi, HV_BINOP_POW, 1, m, &cBinop_Ecb9QWfi_sendMessage);
  cMsg_FcrmkHh8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_OPihSGBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_WqU0f0qh, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_wughi7B3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DTKY6MwB, 1, m, &cIf_DTKY6MwB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_enfSzgoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ahXPsb2J, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ahXPsb2J_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IOK2yfCZ, HV_BINOP_EQ, 1, m, &cBinop_IOK2yfCZ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_K7tGpDhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_agLfLepr, HV_BINOP_ADD, 0, m, &cBinop_agLfLepr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_agLfLepr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EcByMtJy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sg9KFJUO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ahXPsb2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OPihSGBR, 1, m, &cIf_OPihSGBR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IOK2yfCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H3RTU0zN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_H3RTU0zN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WqU0f0qh, m);
}

void Heavy_WSTD_3Q::cCast_SuEuoRdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K7tGpDhC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_lCDDLr8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_agLfLepr, HV_BINOP_ADD, 1, m, &cBinop_agLfLepr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ahXPsb2J, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ahXPsb2J_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IOK2yfCZ, HV_BINOP_EQ, 0, m, &cBinop_IOK2yfCZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5AbMuZlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tjR6pUMU, 0, m, &cVar_tjR6pUMU_sendMessage);
}

void Heavy_WSTD_3Q::cVar_QXyuS49D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VxhNJSR2_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_tyxbew7p, 0, m, &cIf_tyxbew7p_sendMessage);
}

void Heavy_WSTD_3Q::cIf_tyxbew7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4brL1dRB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_Lp1SuP4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_u55Q667O_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_kFxHjUbY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_chADJPRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_I1ElB2dz, HV_BINOP_POW, 0, m, &cBinop_I1ElB2dz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_I1ElB2dz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1KcN34NJ, 0, m, &cIf_1KcN34NJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VGANbUBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_SoWW7FRe_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QMVHXBX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Lp1SuP4R, 0, m, &cIf_Lp1SuP4R_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hkOI9a4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Cq2Kbj7s_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Cq2Kbj7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Lp1SuP4R, 1, m, &cIf_Lp1SuP4R_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kFxHjUbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_VGANbUBB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_u55Q667O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_1KcN34NJ, 0, m, &cIf_1KcN34NJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SoWW7FRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I1ElB2dz, HV_BINOP_POW, 1, m, &cBinop_I1ElB2dz_sendMessage);
  cMsg_chADJPRy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_1KcN34NJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5Oko2Dv1_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lqtL6b6C_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_3W2Yf9zL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_VxhNJSR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tyxbew7p, 1, m, &cIf_tyxbew7p_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4brL1dRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L2W8hsAr, HV_BINOP_GREATER_THAN, 1, m, &cBinop_L2W8hsAr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hbkn36El, HV_BINOP_EQ, 1, m, &cBinop_hbkn36El_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_nYmInICZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UfEUjLDS, HV_BINOP_ADD, 0, m, &cBinop_UfEUjLDS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UfEUjLDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hkOI9a4U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QMVHXBX2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_L2W8hsAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1KcN34NJ, 1, m, &cIf_1KcN34NJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hbkn36El_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZpJnbBUg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ZpJnbBUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5Oko2Dv1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lqtL6b6C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_3W2Yf9zL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_k5L8BWJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QXyuS49D, 0, m, &cVar_QXyuS49D_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Ve3cfG70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nYmInICZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_rvkZquzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UfEUjLDS, HV_BINOP_ADD, 1, m, &cBinop_UfEUjLDS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_L2W8hsAr, HV_BINOP_GREATER_THAN, 0, m, &cBinop_L2W8hsAr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hbkn36El, HV_BINOP_EQ, 0, m, &cBinop_hbkn36El_sendMessage);
}

void Heavy_WSTD_3Q::cVar_swwO7OhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BDWGsfUX_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_QByRUHMr, 0, m, &cIf_QByRUHMr_sendMessage);
}

void Heavy_WSTD_3Q::cIf_QByRUHMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2llDAfDi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_X9gX4Lvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_C27LsCtK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_FiH89Tgu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_A7ZLswMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_39csgyH3, HV_BINOP_POW, 0, m, &cBinop_39csgyH3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_39csgyH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_p2hKPTeT, 0, m, &cIf_p2hKPTeT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wlpfYBz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_3qbgolAm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kJIcONqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cf1OlxDA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TjObz2yX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X9gX4Lvc, 0, m, &cIf_X9gX4Lvc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cf1OlxDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X9gX4Lvc, 1, m, &cIf_X9gX4Lvc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FiH89Tgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_wlpfYBz4_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_C27LsCtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_p2hKPTeT, 0, m, &cIf_p2hKPTeT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3qbgolAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_39csgyH3, HV_BINOP_POW, 1, m, &cBinop_39csgyH3_sendMessage);
  cMsg_A7ZLswMM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_p2hKPTeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_EK2byhKD, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_BDWGsfUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QByRUHMr, 1, m, &cIf_QByRUHMr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2llDAfDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KpLUD52e, HV_BINOP_GREATER_THAN, 1, m, &cBinop_KpLUD52e_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_F9WwBjjG, HV_BINOP_EQ, 1, m, &cBinop_F9WwBjjG_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_SGS6e8Wc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_92fliXri, HV_BINOP_ADD, 0, m, &cBinop_92fliXri_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_92fliXri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kJIcONqK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TjObz2yX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KpLUD52e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_p2hKPTeT, 1, m, &cIf_p2hKPTeT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_F9WwBjjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YjFaUevH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_YjFaUevH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_EK2byhKD, m);
}

void Heavy_WSTD_3Q::cCast_0rj6Z5AH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_92fliXri, HV_BINOP_ADD, 1, m, &cBinop_92fliXri_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KpLUD52e, HV_BINOP_GREATER_THAN, 0, m, &cBinop_KpLUD52e_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_F9WwBjjG, HV_BINOP_EQ, 0, m, &cBinop_F9WwBjjG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YaD47LZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_swwO7OhS, 0, m, &cVar_swwO7OhS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FANUdtyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SGS6e8Wc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_MvyoNL7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_x8FVbZCt, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_vEENpFzx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QBoxrI6h, 0, m, &cSlice_QBoxrI6h_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vwG8rcjq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_QBoxrI6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CxWY0gfI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CxWY0gfI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_IZ1EPsb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CxWY0gfI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_CxWY0gfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dvLWISwn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_vwG8rcjq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8Sh8lIsW, 0, m, &cSlice_8Sh8lIsW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zkGpOpea_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_8Sh8lIsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Xyi3U7tl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Xyi3U7tl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_3oq5VpUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Xyi3U7tl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Xyi3U7tl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZNXlcsno_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_27A91zQO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_42rlIM2K, 0, m, &cSlice_42rlIM2K_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dlgZpd4H_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_42rlIM2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OAJmitZj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OAJmitZj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_Uugoil3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OAJmitZj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_OAJmitZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hlDnesvV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_dlgZpd4H_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DXUe6KXD, 0, m, &cSlice_DXUe6KXD_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_DXUe6KXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vAF4mWh4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vAF4mWh4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_fOTEKXtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vAF4mWh4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_vAF4mWh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EWsmfZtb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_8EeXweyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ddr4tpGn, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_hyuy0yki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OfGf9hRP, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_vy7Qo5US_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JLPdqsA1, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_buZQCCV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QXz2A6LN, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_DTl5yMzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1sVwIh9U, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ehBwKCXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_utvn41qS_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_utvn41qS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pj0TAy39, HV_BINOP_DIVIDE, 1, m, &cBinop_pj0TAy39_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pTZ9Qf5B_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_h7SdjT2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_p9abODNW_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_3wTtwXWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_h7SdjT2Q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_p9abODNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pj0TAy39, HV_BINOP_DIVIDE, 0, m, &cBinop_pj0TAy39_sendMessage);
}

void Heavy_WSTD_3Q::cCast_pTZ9Qf5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3wTtwXWy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_pj0TAy39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bJSILkVZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_bJSILkVZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bJSILkVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aMr0i4LD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_peqRyizs_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_o9fQygTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nnMZHQcg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_8LBYjJjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_roVPHQVv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_UyzNDUTO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_A83E8s2l_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_A83E8s2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bJSILkVZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_bJSILkVZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LadIENJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_0xyDFv6Q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0xyDFv6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dAXeb3Zh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_2SmUeIIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yK1MyeK3, 1, m, &cVar_yK1MyeK3_sendMessage);
}

void Heavy_WSTD_3Q::cVar_yK1MyeK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N4PAhFiR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_iIFKfZeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MIxzSIZF, HV_BINOP_MULTIPLY, 1, m, &cBinop_MIxzSIZF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Pq4bWJY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iIFKfZeL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_X2ZT5BzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_bCVeO0Pl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bCVeO0Pl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KsbRuz5A, HV_BINOP_MULTIPLY, 1, m, &cBinop_KsbRuz5A_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_93QtKxdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nfNhN18z, HV_BINOP_MULTIPLY, 1, m, &cBinop_nfNhN18z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0kZJtgcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_93QtKxdU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_f1qOzUQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0FtIFOvt, HV_BINOP_MULTIPLY, 1, m, &cBinop_0FtIFOvt_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_LYZBzSCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QJCpV3WU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QJCpV3WU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4NmeCpBv, HV_BINOP_MULTIPLY, 1, m, &cBinop_4NmeCpBv_sendMessage);
}

void Heavy_WSTD_3Q::cVar_gAFxfzIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i5fj6CLk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_UyzNDUTO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kZVkywDL_sendMessage);
}

void Heavy_WSTD_3Q::cVar_F4RFNiwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_LadIENJ8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_aMr0i4LD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_o9fQygTW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_peqRyizs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_8LBYjJjs_sendMessage);
}

void Heavy_WSTD_3Q::cSend_nnMZHQcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jwV76A7C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_roVPHQVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RZX1LvxC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_dF1k28b9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AqAm1xSG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_dAXeb3Zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gOVh2Apq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gOVh2Apq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rYa0sdQn, HV_BINOP_MULTIPLY, 1, m, &cBinop_rYa0sdQn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rYa0sdQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uy43Ugh5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uy43Ugh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dF1k28b9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_N4PAhFiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dg9Bu7Cv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dg9Bu7Cv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sVXAxyS4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KcV96RkG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bQByWy5z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WY1fpAnh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PFSkUZor_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RzqAIovD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MIxzSIZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8EeXweyA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_KsbRuz5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hyuy0yki_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_nfNhN18z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vy7Qo5US_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_0FtIFOvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_buZQCCV6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_4NmeCpBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DTl5yMzL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_6JpmhkqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F4RFNiwP, 1, m, &cVar_F4RFNiwP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CFENw9wf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gAFxfzIG, 0, m, &cVar_gAFxfzIG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PFSkUZor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KsbRuz5A, HV_BINOP_MULTIPLY, 0, m, &cBinop_KsbRuz5A_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KcV96RkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4NmeCpBv, HV_BINOP_MULTIPLY, 0, m, &cBinop_4NmeCpBv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WY1fpAnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nfNhN18z, HV_BINOP_MULTIPLY, 0, m, &cBinop_nfNhN18z_sendMessage);
}

void Heavy_WSTD_3Q::cCast_sVXAxyS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_RzqAIovD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MIxzSIZF, HV_BINOP_MULTIPLY, 0, m, &cBinop_MIxzSIZF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bQByWy5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0FtIFOvt, HV_BINOP_MULTIPLY, 0, m, &cBinop_0FtIFOvt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kZVkywDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yK1MyeK3, 0, m, &cVar_yK1MyeK3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_i5fj6CLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F4RFNiwP, 0, m, &cVar_F4RFNiwP_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_h9EZa5Q0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k4Hwig4i, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_35ZKw6gT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uK0r9fs7, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_1ZItXg0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JXJoo8d9, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_qUW67mO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bjx4SWg8, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_nHCt9PRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nSU7pMCM_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_nSU7pMCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PJmO30jZ, HV_BINOP_DIVIDE, 1, m, &cBinop_PJmO30jZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HQSA0wyN_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_7fAXiawE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_GvPU9SYV_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_LHnpKHkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_7fAXiawE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GvPU9SYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PJmO30jZ, HV_BINOP_DIVIDE, 0, m, &cBinop_PJmO30jZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HQSA0wyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LHnpKHkE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_PJmO30jZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ybgXRBpI, HV_BINOP_MULTIPLY, 1, m, &cBinop_ybgXRBpI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ybgXRBpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wA02Twwx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uhecJTXd_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_YDeoJerj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WW7ZXrTJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_AaeIOpUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_I3G39nYr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_e69LLD6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_5DF6f7nf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5DF6f7nf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ybgXRBpI, HV_BINOP_MULTIPLY, 0, m, &cBinop_ybgXRBpI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1S4V67Bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_juPacowG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_juPacowG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BL1oL7ND_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Ei9Rv0Tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OYxywcac, HV_BINOP_MULTIPLY, 1, m, &cBinop_OYxywcac_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HyYWylM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0fiOVuvu, 1, m, &cVar_0fiOVuvu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Aua2tjTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LsfZjnX5, HV_BINOP_MULTIPLY, 1, m, &cBinop_LsfZjnX5_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_pc2VgGNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_h6aqy4gZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_h6aqy4gZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B2etS9CF, HV_BINOP_MULTIPLY, 1, m, &cBinop_B2etS9CF_sendMessage);
}

void Heavy_WSTD_3Q::cVar_0fiOVuvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iEqIkz1t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_oqpJ5hHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kiyikNsa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_e69LLD6d_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7HrmeQDo_sendMessage);
}

void Heavy_WSTD_3Q::cVar_Q7f1Ys8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_1S4V67Bg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uhecJTXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_AaeIOpUH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wA02Twwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_YDeoJerj_sendMessage);
}

void Heavy_WSTD_3Q::cSend_WW7ZXrTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DoHBD7yY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_I3G39nYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cWe5nbcU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_HCkJGDE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aFrtGlL0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_BL1oL7ND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Joi67wrX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Joi67wrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HH2ATJbY, HV_BINOP_MULTIPLY, 1, m, &cBinop_HH2ATJbY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HH2ATJbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LKXqiSvq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LKXqiSvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HCkJGDE8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_iEqIkz1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MwW0UpjK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MwW0UpjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OPfh9KVR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3CLNsGb4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yYy9z3cy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0Gf3MVqv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Nu1lxieO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h9EZa5Q0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_OYxywcac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_35ZKw6gT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_LsfZjnX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1ZItXg0Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_B2etS9CF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qUW67mO3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_RnyLq7pC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q7f1Ys8F, 1, m, &cVar_Q7f1Ys8F_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0b6PJk0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oqpJ5hHL, 0, m, &cVar_oqpJ5hHL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kiyikNsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q7f1Ys8F, 0, m, &cVar_Q7f1Ys8F_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7HrmeQDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0fiOVuvu, 0, m, &cVar_0fiOVuvu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3CLNsGb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LsfZjnX5, HV_BINOP_MULTIPLY, 0, m, &cBinop_LsfZjnX5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0Gf3MVqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nu1lxieO, HV_BINOP_MULTIPLY, 0, m, &cBinop_Nu1lxieO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OPfh9KVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B2etS9CF, HV_BINOP_MULTIPLY, 0, m, &cBinop_B2etS9CF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yYy9z3cy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OYxywcac, HV_BINOP_MULTIPLY, 0, m, &cBinop_OYxywcac_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_WZEjpL0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6HK1HJXy, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_sqvUfX65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jYNUufTo, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_zA04bmph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ioCZoojV, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_BU4MoqJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ty9fEfvo, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_KCyei4hT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a56DXbSB, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Sg53AJF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lUWxgBgz_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_lUWxgBgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wq9qSDgh, HV_BINOP_DIVIDE, 1, m, &cBinop_Wq9qSDgh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uPC2vJfq_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_fRJSQ3PD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_MgtEIjmW_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_7LCIvWuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_fRJSQ3PD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MgtEIjmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wq9qSDgh, HV_BINOP_DIVIDE, 0, m, &cBinop_Wq9qSDgh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uPC2vJfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7LCIvWuV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Wq9qSDgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f2t7DfkY, HV_BINOP_MULTIPLY, 1, m, &cBinop_f2t7DfkY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_f2t7DfkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9nnsf90n_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L1XihtpY_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_xyQ6ILjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gpXQnxmC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_BRlrqURu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_h2yTsfOZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_YB0FjZat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_WEAbGhkL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WEAbGhkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f2t7DfkY, HV_BINOP_MULTIPLY, 0, m, &cBinop_f2t7DfkY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_V8YmCP6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ETJCuIhc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ETJCuIhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m4DXNWPK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6HfLqyyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IE6dPqGq, HV_BINOP_MULTIPLY, 1, m, &cBinop_IE6dPqGq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_wvi040fs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Cxpq43lE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Cxpq43lE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6HfLqyyq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_oDf6D5S0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_u3aC4vFF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_u3aC4vFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gaIMrN46, HV_BINOP_MULTIPLY, 1, m, &cBinop_gaIMrN46_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zmfxz4tr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h3Np6wsa, HV_BINOP_MULTIPLY, 1, m, &cBinop_h3Np6wsa_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_e6Vnko1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NtbnGO5T_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NtbnGO5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zmfxz4tr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cTMQALMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kCyo4fUb, 1, m, &cVar_kCyo4fUb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pcYNs9ry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fefylhc9, HV_BINOP_MULTIPLY, 1, m, &cBinop_Fefylhc9_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_gAqzq72G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Q7XDFOlt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Q7XDFOlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gaF94oLh, HV_BINOP_MULTIPLY, 1, m, &cBinop_gaF94oLh_sendMessage);
}

void Heavy_WSTD_3Q::cVar_kCyo4fUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lHg8DrFC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_xqkENoxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4yootkBs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_YB0FjZat_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QiZJ4aSs_sendMessage);
}

void Heavy_WSTD_3Q::cVar_waHca9iK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_V8YmCP6Z_sendMessage);
}

void Heavy_WSTD_3Q::cCast_L1XihtpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_BRlrqURu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9nnsf90n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_xyQ6ILjG_sendMessage);
}

void Heavy_WSTD_3Q::cSend_gpXQnxmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hDehFXnc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_h2yTsfOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mGuNJJd8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_NaUf50KB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_D02ji0Hy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_m4DXNWPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_k2fZhndR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_k2fZhndR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c1hSkwjh, HV_BINOP_MULTIPLY, 1, m, &cBinop_c1hSkwjh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_c1hSkwjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_blaP6goZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_blaP6goZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NaUf50KB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_lHg8DrFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_poG01sfd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_poG01sfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBKPcQEI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nhXo42Cu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m60P1hvU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ECyOgao6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E5zwXQrq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pG0mKcOg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IE6dPqGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WZEjpL0v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_gaIMrN46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sqvUfX65_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_h3Np6wsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zA04bmph_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Fefylhc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BU4MoqJN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_gaF94oLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KCyei4hT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_XZCEFnOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xqkENoxp, 0, m, &cVar_xqkENoxp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wSTjpAtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_waHca9iK, 1, m, &cVar_waHca9iK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_E5zwXQrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gaIMrN46, HV_BINOP_MULTIPLY, 0, m, &cBinop_gaIMrN46_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nhXo42Cu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gaF94oLh, HV_BINOP_MULTIPLY, 0, m, &cBinop_gaF94oLh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ECyOgao6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h3Np6wsa, HV_BINOP_MULTIPLY, 0, m, &cBinop_h3Np6wsa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZBKPcQEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_pG0mKcOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IE6dPqGq, HV_BINOP_MULTIPLY, 0, m, &cBinop_IE6dPqGq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_m60P1hvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fefylhc9, HV_BINOP_MULTIPLY, 0, m, &cBinop_Fefylhc9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QiZJ4aSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kCyo4fUb, 0, m, &cVar_kCyo4fUb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4yootkBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_waHca9iK, 0, m, &cVar_waHca9iK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5Oko2Dv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MvyoNL7Q, 1, m, &cIf_MvyoNL7Q_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lrAKshAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_x8FVbZCt, m);
}

void Heavy_WSTD_3Q::cBinop_lqtL6b6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lrAKshAA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3W2Yf9zL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MvyoNL7Q, 0, m, &cIf_MvyoNL7Q_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_GXorgqhk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CJCZI3RY, 0, m, &cSlice_CJCZI3RY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FFD9IaeK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_CJCZI3RY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_V0TLEGvu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_V0TLEGvu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_P3y9nHtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V0TLEGvu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_V0TLEGvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0s3N0Qfc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_0DeadKwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YpxCy83t_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_d2CkKtaU, 0, m, &cIf_d2CkKtaU_sendMessage);
}

void Heavy_WSTD_3Q::cIf_d2CkKtaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GZC19H23_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_LIbQSxVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Ii5FJbUT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Y3yk7fam_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_yD2IeRmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VkaLXkYR, HV_BINOP_POW, 0, m, &cBinop_VkaLXkYR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VkaLXkYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HAIAwjkF, 0, m, &cIf_HAIAwjkF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_G0miwmiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_81KkjpzF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QND69rQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_j194YjG1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Yns1gmc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LIbQSxVX, 0, m, &cIf_LIbQSxVX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_j194YjG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LIbQSxVX, 1, m, &cIf_LIbQSxVX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Y3yk7fam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_G0miwmiS_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Ii5FJbUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_HAIAwjkF, 0, m, &cIf_HAIAwjkF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_81KkjpzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VkaLXkYR, HV_BINOP_POW, 1, m, &cBinop_VkaLXkYR_sendMessage);
  cMsg_yD2IeRmI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_HAIAwjkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_yMW33LKd, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_YpxCy83t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d2CkKtaU, 1, m, &cIf_d2CkKtaU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GZC19H23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HuFKAFGZ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_HuFKAFGZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_E4rEsvMR, HV_BINOP_EQ, 1, m, &cBinop_E4rEsvMR_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_RaugpPTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SQLCDpEz, HV_BINOP_ADD, 0, m, &cBinop_SQLCDpEz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SQLCDpEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QND69rQl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yns1gmc6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HuFKAFGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HAIAwjkF, 1, m, &cIf_HAIAwjkF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_E4rEsvMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vjAEKwBa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_vjAEKwBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_yMW33LKd, m);
}

void Heavy_WSTD_3Q::cCast_7KBCKREh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0DeadKwt, 0, m, &cVar_0DeadKwt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3WnJQT1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RaugpPTw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_bsuSuKMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SQLCDpEz, HV_BINOP_ADD, 1, m, &cBinop_SQLCDpEz_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HuFKAFGZ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_HuFKAFGZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_E4rEsvMR, HV_BINOP_EQ, 0, m, &cBinop_E4rEsvMR_sendMessage);
}

void Heavy_WSTD_3Q::cVar_sNYAY9mm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gidf8wKf_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Wg6k4E55, 0, m, &cIf_Wg6k4E55_sendMessage);
}

void Heavy_WSTD_3Q::cIf_Wg6k4E55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IgQaYJUi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_kzUJ68aU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_rUsZiDM5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_XAgP9jdg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_LjixDtzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0TgZ9Ibs, HV_BINOP_POW, 0, m, &cBinop_0TgZ9Ibs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0TgZ9Ibs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ndqlXJz2, 0, m, &cIf_ndqlXJz2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GFxnVWIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_gX4XX7WO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_P7hEWgPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kzUJ68aU, 0, m, &cIf_kzUJ68aU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZDagT7hq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eLRi9pwd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eLRi9pwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kzUJ68aU, 1, m, &cIf_kzUJ68aU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XAgP9jdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_GFxnVWIB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_rUsZiDM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ndqlXJz2, 0, m, &cIf_ndqlXJz2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gX4XX7WO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0TgZ9Ibs, HV_BINOP_POW, 1, m, &cBinop_0TgZ9Ibs_sendMessage);
  cMsg_LjixDtzI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_ndqlXJz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_EgPf13xU_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zrJQSGXd_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_LUXZcVwi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_gidf8wKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wg6k4E55, 1, m, &cIf_Wg6k4E55_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IgQaYJUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MDlCoqOy, HV_BINOP_GREATER_THAN, 1, m, &cBinop_MDlCoqOy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HxY2EGur, HV_BINOP_EQ, 1, m, &cBinop_HxY2EGur_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_FKd4dGOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Epal9KWb, HV_BINOP_ADD, 0, m, &cBinop_Epal9KWb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Epal9KWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZDagT7hq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P7hEWgPS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MDlCoqOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ndqlXJz2, 1, m, &cIf_ndqlXJz2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HxY2EGur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rielv089_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_Rielv089_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_EgPf13xU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_zrJQSGXd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_LUXZcVwi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZK32N17w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Epal9KWb, HV_BINOP_ADD, 1, m, &cBinop_Epal9KWb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MDlCoqOy, HV_BINOP_GREATER_THAN, 0, m, &cBinop_MDlCoqOy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HxY2EGur, HV_BINOP_EQ, 0, m, &cBinop_HxY2EGur_sendMessage);
}

void Heavy_WSTD_3Q::cCast_elcziwt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sNYAY9mm, 0, m, &cVar_sNYAY9mm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lNCeWRJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FKd4dGOq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_FJMYpTHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZMDfppxx_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_f4fVaY4C, 0, m, &cIf_f4fVaY4C_sendMessage);
}

void Heavy_WSTD_3Q::cIf_f4fVaY4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lifZ6ekz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_FJ7g93VW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_3zPOBSn6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_AAxuaZP1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_nQ9GhEFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sQDodJIM, HV_BINOP_POW, 0, m, &cBinop_sQDodJIM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sQDodJIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T2b55Ebl, 0, m, &cIf_T2b55Ebl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CSX2g1rt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vWoznezc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_61j15RpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FJ7g93VW, 0, m, &cIf_FJ7g93VW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OiXp6Pn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YAqNeGFf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YAqNeGFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FJ7g93VW, 1, m, &cIf_FJ7g93VW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AAxuaZP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_CSX2g1rt_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_3zPOBSn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_T2b55Ebl, 0, m, &cIf_T2b55Ebl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vWoznezc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sQDodJIM, HV_BINOP_POW, 1, m, &cBinop_sQDodJIM_sendMessage);
  cMsg_nQ9GhEFc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_T2b55Ebl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_2q0jgeJQ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_ZMDfppxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f4fVaY4C, 1, m, &cIf_f4fVaY4C_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lifZ6ekz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AKLThJtU, HV_BINOP_GREATER_THAN, 1, m, &cBinop_AKLThJtU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_o4zlZqV1, HV_BINOP_EQ, 1, m, &cBinop_o4zlZqV1_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZLadRvhq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UE136kqy, HV_BINOP_ADD, 0, m, &cBinop_UE136kqy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UE136kqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OiXp6Pn4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_61j15RpQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AKLThJtU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T2b55Ebl, 1, m, &cIf_T2b55Ebl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_o4zlZqV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IWPMcrMB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_IWPMcrMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_2q0jgeJQ, m);
}

void Heavy_WSTD_3Q::cCast_8UXHzhpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UE136kqy, HV_BINOP_ADD, 1, m, &cBinop_UE136kqy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AKLThJtU, HV_BINOP_GREATER_THAN, 0, m, &cBinop_AKLThJtU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_o4zlZqV1, HV_BINOP_EQ, 0, m, &cBinop_o4zlZqV1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kgnmAUqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FJMYpTHG, 0, m, &cVar_FJMYpTHG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7LYUsBAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZLadRvhq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_a36d07XQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_K3REoeJ9, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_VhcuStVI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XqGm2FbS, 0, m, &cSlice_XqGm2FbS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gg6m4GXK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_XqGm2FbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cIhxR8cy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cIhxR8cy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_ZObyBh5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cIhxR8cy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_cIhxR8cy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kNJZrHXo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_gg6m4GXK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gj3AH7PV, 0, m, &cSlice_gj3AH7PV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GXorgqhk_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_gj3AH7PV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Yum30u2f_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Yum30u2f_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_4R01CzEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Yum30u2f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Yum30u2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3GkujMSm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_FFD9IaeK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sl2m26uN, 0, m, &cSlice_sl2m26uN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nnvlgEOt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_sl2m26uN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oCVsvIax_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oCVsvIax_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_3UzxmPRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oCVsvIax_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_oCVsvIax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JA4lJ6LI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_nnvlgEOt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_grUJrlFn, 0, m, &cSlice_grUJrlFn_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_grUJrlFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MGqpiJ08_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MGqpiJ08_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_1IwtQE1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MGqpiJ08_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_MGqpiJ08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KSgmohsg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_hXAhhQ5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZM6GHzWL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_9GDy1Oxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uwsG7kfd, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_FFrw3gkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_69IfdjVs, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Px5MNRFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iDOvWLYq, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_V7dQzncA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ctdeXdzV, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_eFf2yOcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JTVtiV3R_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_JTVtiV3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1sqDCmoQ, HV_BINOP_DIVIDE, 1, m, &cBinop_1sqDCmoQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2pWMWma7_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_J6eQMLzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_cwsoZo4v_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Cqekf2RI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_J6eQMLzQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cwsoZo4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1sqDCmoQ, HV_BINOP_DIVIDE, 0, m, &cBinop_1sqDCmoQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2pWMWma7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cqekf2RI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1sqDCmoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MCJpQ34q, HV_BINOP_MULTIPLY, 1, m, &cBinop_MCJpQ34q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MCJpQ34q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vQ79H4ja_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LVSlBSL7_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_mZJQCHAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JMMTu63X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_htCLK9g2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hx2jTSp0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_RsUWk0qR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_9uQfu5tG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9uQfu5tG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MCJpQ34q, HV_BINOP_MULTIPLY, 0, m, &cBinop_MCJpQ34q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6XezkfOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_nJGSh1jv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nJGSh1jv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GZ5H6NtL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_FTFBEPfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_23xjBPFO, 1, m, &cVar_23xjBPFO_sendMessage);
}

void Heavy_WSTD_3Q::cVar_23xjBPFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c0fOIPwP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3N61CMul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IU07p8Qv, HV_BINOP_MULTIPLY, 1, m, &cBinop_IU07p8Qv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RHVXf807_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3N61CMul_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XLHV0MKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_J5Olj0xZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_J5Olj0xZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PoF83vB5, HV_BINOP_MULTIPLY, 1, m, &cBinop_PoF83vB5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_a8AdJv5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_20aTUjal, HV_BINOP_MULTIPLY, 1, m, &cBinop_20aTUjal_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MTq8gYlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_a8AdJv5r_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vFqLlNgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k2tTksyw, HV_BINOP_MULTIPLY, 1, m, &cBinop_k2tTksyw_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_DWl1tDww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jlM6Wzi6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jlM6Wzi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XUyGO3u7, HV_BINOP_MULTIPLY, 1, m, &cBinop_XUyGO3u7_sendMessage);
}

void Heavy_WSTD_3Q::cVar_nb8ypYfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HukooNAb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_RsUWk0qR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PFJ2t3P2_sendMessage);
}

void Heavy_WSTD_3Q::cVar_sKyJInti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_6XezkfOo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vQ79H4ja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_mZJQCHAG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LVSlBSL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_htCLK9g2_sendMessage);
}

void Heavy_WSTD_3Q::cSend_JMMTu63X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8DZIMJP1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_hx2jTSp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dMlkV7ju_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_VPWWHoO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7q1OYDUE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_GZ5H6NtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jVGWJ4JY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jVGWJ4JY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9x4LWoAz, HV_BINOP_MULTIPLY, 1, m, &cBinop_9x4LWoAz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9x4LWoAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qI92Sr14_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qI92Sr14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VPWWHoO1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_c0fOIPwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_U4t4AH8S_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_U4t4AH8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XgIig37E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LPWUMDH2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2KnGylWP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bB1Us0pD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fc3Stj5S_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bhWKgI80_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IU07p8Qv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hXAhhQ5Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_PoF83vB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9GDy1Oxc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_20aTUjal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FFrw3gkn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_k2tTksyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Px5MNRFD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_XUyGO3u7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V7dQzncA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_JKhDxy54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nb8ypYfH, 0, m, &cVar_nb8ypYfH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xous2spP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sKyJInti, 1, m, &cVar_sKyJInti_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bB1Us0pD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_20aTUjal, HV_BINOP_MULTIPLY, 0, m, &cBinop_20aTUjal_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XgIig37E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_bhWKgI80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IU07p8Qv, HV_BINOP_MULTIPLY, 0, m, &cBinop_IU07p8Qv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2KnGylWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k2tTksyw, HV_BINOP_MULTIPLY, 0, m, &cBinop_k2tTksyw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Fc3Stj5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PoF83vB5, HV_BINOP_MULTIPLY, 0, m, &cBinop_PoF83vB5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LPWUMDH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XUyGO3u7, HV_BINOP_MULTIPLY, 0, m, &cBinop_XUyGO3u7_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HukooNAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sKyJInti, 0, m, &cVar_sKyJInti_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PFJ2t3P2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_23xjBPFO, 0, m, &cVar_23xjBPFO_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_xYDSZS6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gk2Ydlzh, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_50pljY3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Uwuuf8Bq, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_xtXl68b3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ILWAHCbC, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_PaxbbvX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gjCMOH9Y, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_7ltYvoda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sbfL6cc0_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_sbfL6cc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m1XWPVnI, HV_BINOP_DIVIDE, 1, m, &cBinop_m1XWPVnI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OTzegZFY_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_4l7uefbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_r30p9k8L_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_91FOIdYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_4l7uefbl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_r30p9k8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m1XWPVnI, HV_BINOP_DIVIDE, 0, m, &cBinop_m1XWPVnI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OTzegZFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_91FOIdYo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_m1XWPVnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GFjC5c38, HV_BINOP_MULTIPLY, 1, m, &cBinop_GFjC5c38_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GFjC5c38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9lB5wDCG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LcY0Kmao_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_gUKhoIDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NU0TldyN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_nFG8trId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KMxl6Yn4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_xZUh9YV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_m9CBidnQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_m9CBidnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GFjC5c38, HV_BINOP_MULTIPLY, 0, m, &cBinop_GFjC5c38_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EdBQu4gS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_AnVD1p17_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AnVD1p17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FNIlKnjN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_B3YNGUxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W0kPw9Zf, HV_BINOP_MULTIPLY, 1, m, &cBinop_W0kPw9Zf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_shCRNy2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wlBdiykf, 1, m, &cVar_wlBdiykf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ICLMGZ6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3olXFeY5, HV_BINOP_MULTIPLY, 1, m, &cBinop_3olXFeY5_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_bYw0LZMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_L3HS38LD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_L3HS38LD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BG6xQQMX, HV_BINOP_MULTIPLY, 1, m, &cBinop_BG6xQQMX_sendMessage);
}

void Heavy_WSTD_3Q::cVar_wlBdiykf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2xV7TdfK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_HGEEIo3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FDLzop6K_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_xZUh9YV0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G3UZiq5U_sendMessage);
}

void Heavy_WSTD_3Q::cVar_reEasnWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_EdBQu4gS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9lB5wDCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_gUKhoIDM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LcY0Kmao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_nFG8trId_sendMessage);
}

void Heavy_WSTD_3Q::cSend_NU0TldyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wsaqC5pZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_KMxl6Yn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tXz3gF2J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_7tCNzDSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iSYoLLns_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_FNIlKnjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9hDKWwOw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9hDKWwOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HwdJ8yOL, HV_BINOP_MULTIPLY, 1, m, &cBinop_HwdJ8yOL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HwdJ8yOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_e0A5yin6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_e0A5yin6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7tCNzDSI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_2xV7TdfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rgvcnpM7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rgvcnpM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_viKi1O8K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0VX5lV3s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lMEoztAu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_diyWr5iV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bV05DW61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xYDSZS6x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_W0kPw9Zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_50pljY3b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3olXFeY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xtXl68b3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_BG6xQQMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PaxbbvX8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_RUUPyiC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_reEasnWf, 1, m, &cVar_reEasnWf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_64oTqyj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HGEEIo3N, 0, m, &cVar_HGEEIo3N_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FDLzop6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_reEasnWf, 0, m, &cVar_reEasnWf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_G3UZiq5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wlBdiykf, 0, m, &cVar_wlBdiykf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0VX5lV3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3olXFeY5, HV_BINOP_MULTIPLY, 0, m, &cBinop_3olXFeY5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_diyWr5iV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bV05DW61, HV_BINOP_MULTIPLY, 0, m, &cBinop_bV05DW61_sendMessage);
}

void Heavy_WSTD_3Q::cCast_viKi1O8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BG6xQQMX, HV_BINOP_MULTIPLY, 0, m, &cBinop_BG6xQQMX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lMEoztAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W0kPw9Zf, HV_BINOP_MULTIPLY, 0, m, &cBinop_W0kPw9Zf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_uwpI3v3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iIktE68K, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_MtKVAtJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KM94CC1R, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_3RTQ3HAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CCFqq9Pj, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_VHSj5ye6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_omhcwdIG, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_JAjbciv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_epC4gVaG, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_RJtkg48g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FaokNhbZ_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_FaokNhbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVeM3xIp, HV_BINOP_DIVIDE, 1, m, &cBinop_bVeM3xIp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NWL7dH1J_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_fuZxMV7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_F88DVV8c_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_m6YJkoVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_fuZxMV7U_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_F88DVV8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVeM3xIp, HV_BINOP_DIVIDE, 0, m, &cBinop_bVeM3xIp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NWL7dH1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m6YJkoVu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_bVeM3xIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IYkXG78J, HV_BINOP_MULTIPLY, 1, m, &cBinop_IYkXG78J_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IYkXG78J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E0Mhssmi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UleJBKRG_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_fVd6HeQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eAKSJt0O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_nS66n37q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_npjZq5dD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_mXhRFgvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_CqMmggeV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CqMmggeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IYkXG78J, HV_BINOP_MULTIPLY, 0, m, &cBinop_IYkXG78J_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8esxrw93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_WUT5QE9K_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WUT5QE9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E2TetnNJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Bvf7Uh3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R1gOUZ0t, HV_BINOP_MULTIPLY, 1, m, &cBinop_R1gOUZ0t_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_4oNQkHZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nMWGDzJ0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nMWGDzJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Bvf7Uh3i_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_UmiMdGBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rzOV9epP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rzOV9epP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0mxfAgCI, HV_BINOP_MULTIPLY, 1, m, &cBinop_0mxfAgCI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Tv6Hbw5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qxIjQpuO, HV_BINOP_MULTIPLY, 1, m, &cBinop_qxIjQpuO_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_j5CYx15O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_t5RHoxep_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_t5RHoxep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Tv6Hbw5F_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QZp24w99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EQMI0sLu, 1, m, &cVar_EQMI0sLu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XvWZVJvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ajrchUyw, HV_BINOP_MULTIPLY, 1, m, &cBinop_ajrchUyw_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_s1ShXFrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_snG5jiqT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_snG5jiqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rqzrgH0K, HV_BINOP_MULTIPLY, 1, m, &cBinop_rqzrgH0K_sendMessage);
}

void Heavy_WSTD_3Q::cVar_EQMI0sLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tryHom0b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_dcTUBvML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9zADGbGh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_mXhRFgvj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ujxo2CdC_sendMessage);
}

void Heavy_WSTD_3Q::cVar_hV1mLLIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_8esxrw93_sendMessage);
}

void Heavy_WSTD_3Q::cCast_UleJBKRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_nS66n37q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_E0Mhssmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_fVd6HeQB_sendMessage);
}

void Heavy_WSTD_3Q::cSend_eAKSJt0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OpZFe3XX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_npjZq5dD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zYybn6QO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_vh2fIJuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HvfnnCOc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_E2TetnNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kt6spqE0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kt6spqE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f72KdTIU, HV_BINOP_MULTIPLY, 1, m, &cBinop_f72KdTIU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_f72KdTIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TyFit1ZI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TyFit1ZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vh2fIJuE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_tryHom0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_YFHHI2VY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YFHHI2VY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oiixMuNF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4aJl3gr6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eOIisqLr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KH5RbpSK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2HWy8vGi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZWYWzuOF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_R1gOUZ0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uwpI3v3f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_0mxfAgCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MtKVAtJN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_qxIjQpuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3RTQ3HAT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ajrchUyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VHSj5ye6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_rqzrgH0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JAjbciv6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_MyVfy8py_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hV1mLLIF, 1, m, &cVar_hV1mLLIF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_j9scffTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dcTUBvML, 0, m, &cVar_dcTUBvML_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2HWy8vGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0mxfAgCI, HV_BINOP_MULTIPLY, 0, m, &cBinop_0mxfAgCI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4aJl3gr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rqzrgH0K, HV_BINOP_MULTIPLY, 0, m, &cBinop_rqzrgH0K_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KH5RbpSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qxIjQpuO, HV_BINOP_MULTIPLY, 0, m, &cBinop_qxIjQpuO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_oiixMuNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_ZWYWzuOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R1gOUZ0t, HV_BINOP_MULTIPLY, 0, m, &cBinop_R1gOUZ0t_sendMessage);
}

void Heavy_WSTD_3Q::cCast_eOIisqLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ajrchUyw, HV_BINOP_MULTIPLY, 0, m, &cBinop_ajrchUyw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9zADGbGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hV1mLLIF, 0, m, &cVar_hV1mLLIF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ujxo2CdC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EQMI0sLu, 0, m, &cVar_EQMI0sLu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EgPf13xU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a36d07XQ, 1, m, &cIf_a36d07XQ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_7IJQAV9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_K3REoeJ9, m);
}

void Heavy_WSTD_3Q::cBinop_zrJQSGXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7IJQAV9o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_LUXZcVwi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a36d07XQ, 0, m, &cIf_a36d07XQ_sendMessage);
}

void Heavy_WSTD_3Q::cVar_HF4yiJlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XZ40z6Vm, HV_BINOP_DIVIDE, 0, m, &cBinop_XZ40z6Vm_sendMessage);
}

void Heavy_WSTD_3Q::cVar_MLDXgy6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DCoT1Qce, HV_BINOP_DIVIDE, 1, m, &cBinop_DCoT1Qce_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XZ40z6Vm, HV_BINOP_DIVIDE, 1, m, &cBinop_XZ40z6Vm_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_X4g1fBrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fdMkmWTc, HV_BINOP_DIVIDE, 0, m, &cBinop_fdMkmWTc_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_OSRhud5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fdMkmWTc, HV_BINOP_DIVIDE, 1, m, &cBinop_fdMkmWTc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CzSd0gVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HF4yiJlp, 0, m, &cVar_HF4yiJlp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AaWE2AJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MLDXgy6u, 0, m, &cVar_MLDXgy6u_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1xs8rEVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DCoT1Qce, HV_BINOP_DIVIDE, 0, m, &cBinop_DCoT1Qce_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DCoT1Qce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_X4g1fBrN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XZ40z6Vm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_OSRhud5h_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fdMkmWTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_qYUOJKum_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_GZbsvNkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_sKAxCo7I_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aLxj2Ri4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_WE6Bk8kA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qYUOJKum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_aLxj2Ri4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WE6Bk8kA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_GZbsvNkv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sKAxCo7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jc6dbVAp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_QIRXp5jO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vEENpFzx_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VhcuStVI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_m9aNVENT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vEENpFzx_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VhcuStVI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_szII0RJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vEENpFzx_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VhcuStVI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_vXCpXctX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vEENpFzx_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VhcuStVI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_jc6dbVAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_vEENpFzx_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VhcuStVI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_OrQTAAnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_W2Dg1HGf, 0, m, &cVar_W2Dg1HGf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_pzruHMUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_54KizWyd, 0, m, &cVar_54KizWyd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OQ5EY8s1, 0, m, &cVar_OQ5EY8s1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OQtowliN, 0, m, &cVar_OQtowliN_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_TDQylHje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_54KizWyd, 0, m, &cVar_54KizWyd_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_zluhRfkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OQ5EY8s1, 0, m, &cVar_OQ5EY8s1_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_fYGtwueS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OQtowliN, 0, m, &cVar_OQtowliN_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_nIaxJGIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oqpJ5hHL, 0, m, &cVar_oqpJ5hHL_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_EWsmfZtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RnyLq7pC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0b6PJk0p_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_dvLWISwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5AbMuZlU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lCDDLr8q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SuEuoRdK_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_hlDnesvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YaD47LZj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0rj6Z5AH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FANUdtyc_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZNXlcsno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k5L8BWJd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rvkZquzd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ve3cfG70_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_TJFdHzim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ehBwKCXI_sendMessage(_c, 0, m);
  cMsg_nHCt9PRk_sendMessage(_c, 0, m);
  cMsg_Sg53AJF2_sendMessage(_c, 0, m);
  cMsg_eFf2yOcX_sendMessage(_c, 0, m);
  cMsg_7ltYvoda_sendMessage(_c, 0, m);
  cMsg_RJtkg48g_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gAFxfzIG, 0, m, &cVar_gAFxfzIG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oqpJ5hHL, 0, m, &cVar_oqpJ5hHL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xqkENoxp, 0, m, &cVar_xqkENoxp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nb8ypYfH, 0, m, &cVar_nb8ypYfH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HGEEIo3N, 0, m, &cVar_HGEEIo3N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dcTUBvML, 0, m, &cVar_dcTUBvML_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_m4z3hphF, 0, m, &cVar_m4z3hphF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tjR6pUMU, 0, m, &cVar_tjR6pUMU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QXyuS49D, 0, m, &cVar_QXyuS49D_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_swwO7OhS, 0, m, &cVar_swwO7OhS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IZ1EPsb6, 0, m, &cVar_IZ1EPsb6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3oq5VpUG, 0, m, &cVar_3oq5VpUG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Uugoil3L, 0, m, &cVar_Uugoil3L_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fOTEKXtn, 0, m, &cVar_fOTEKXtn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P3y9nHtD, 0, m, &cVar_P3y9nHtD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0DeadKwt, 0, m, &cVar_0DeadKwt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sNYAY9mm, 0, m, &cVar_sNYAY9mm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FJMYpTHG, 0, m, &cVar_FJMYpTHG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZObyBh5u, 0, m, &cVar_ZObyBh5u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4R01CzEN, 0, m, &cVar_4R01CzEN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3UzxmPRb, 0, m, &cVar_3UzxmPRb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1IwtQE1x, 0, m, &cVar_1IwtQE1x_sendMessage);
  cMsg_pzruHMUC_sendMessage(_c, 0, m);
  cMsg_OrQTAAnR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_jwV76A7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rYa0sdQn, HV_BINOP_MULTIPLY, 0, m, &cBinop_rYa0sdQn_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_RZX1LvxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Pq4bWJY3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_X2ZT5BzY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0kZJtgcs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_f1qOzUQ5_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_AqAm1xSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2SmUeIIQ_sendMessage);
  cMsg_LYZBzSCD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_DoHBD7yY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HH2ATJbY, HV_BINOP_MULTIPLY, 0, m, &cBinop_HH2ATJbY_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_cWe5nbcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Aua2tjTx_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_aFrtGlL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nu1lxieO, HV_BINOP_MULTIPLY, 1, m, &cBinop_Nu1lxieO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Ei9Rv0Tm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HyYWylM4_sendMessage);
  cMsg_pc2VgGNw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_hDehFXnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c1hSkwjh, HV_BINOP_MULTIPLY, 0, m, &cBinop_c1hSkwjh_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_mGuNJJd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wvi040fs_sendMessage(_c, 0, m);
  cMsg_oDf6D5S0_sendMessage(_c, 0, m);
  cMsg_e6Vnko1n_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_pcYNs9ry_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_D02ji0Hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cTMQALMO_sendMessage);
  cMsg_gAqzq72G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_0s3N0Qfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HGEEIo3N, 0, m, &cVar_HGEEIo3N_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_KSgmohsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RUUPyiC7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_64oTqyj3_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_kNJZrHXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7KBCKREh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bsuSuKMf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3WnJQT1u_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_JA4lJ6LI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kgnmAUqC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8UXHzhpg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7LYUsBAq_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_3GkujMSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_elcziwt1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZK32N17w_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lNCeWRJ0_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_8DZIMJP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9x4LWoAz, HV_BINOP_MULTIPLY, 0, m, &cBinop_9x4LWoAz_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_dMlkV7ju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RHVXf807_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_XLHV0MKs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MTq8gYlR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_vFqLlNgn_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_7q1OYDUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_FTFBEPfU_sendMessage);
  cMsg_DWl1tDww_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_wsaqC5pZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HwdJ8yOL, HV_BINOP_MULTIPLY, 0, m, &cBinop_HwdJ8yOL_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_tXz3gF2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ICLMGZ6J_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_iSYoLLns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bV05DW61, HV_BINOP_MULTIPLY, 1, m, &cBinop_bV05DW61_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_B3YNGUxa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_shCRNy2L_sendMessage);
  cMsg_bYw0LZMU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_OpZFe3XX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f72KdTIU, HV_BINOP_MULTIPLY, 0, m, &cBinop_f72KdTIU_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_zYybn6QO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4oNQkHZw_sendMessage(_c, 0, m);
  cMsg_UmiMdGBZ_sendMessage(_c, 0, m);
  cMsg_j5CYx15O_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_XvWZVJvi_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_HvfnnCOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QZp24w99_sendMessage);
  cMsg_s1ShXFrp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_WSJSJyPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W2Dg1HGf, 0, m, &cVar_W2Dg1HGf_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_ddr4tpGn, VOf(Bf0));
    __hv_line_f(&sLine_OfGf9hRP, VOf(Bf1));
    __hv_line_f(&sLine_JLPdqsA1, VOf(Bf2));
    __hv_line_f(&sLine_QXz2A6LN, VOf(Bf3));
    __hv_line_f(&sLine_1sVwIh9U, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_Nrc9u3Lv, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_WqU0f0qh, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_k4Hwig4i, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_uK0r9fs7, VOf(Bf1));
    __hv_line_f(&sLine_JXJoo8d9, VOf(Bf0));
    __hv_line_f(&sLine_Bjx4SWg8, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_ZaUcHPZ2, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_x8FVbZCt, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_6HK1HJXy, VOf(Bf5));
    __hv_line_f(&sLine_jYNUufTo, VOf(Bf1));
    __hv_line_f(&sLine_ioCZoojV, VOf(Bf2));
    __hv_line_f(&sLine_Ty9fEfvo, VOf(Bf4));
    __hv_line_f(&sLine_a56DXbSB, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_BlZLPTNS, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_EK2byhKD, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_ZM6GHzWL, VOf(Bf6));
    __hv_line_f(&sLine_uwsG7kfd, VOf(Bf2));
    __hv_line_f(&sLine_69IfdjVs, VOf(Bf1));
    __hv_line_f(&sLine_iDOvWLYq, VOf(Bf5));
    __hv_line_f(&sLine_ctdeXdzV, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_pBPNOceK, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_yMW33LKd, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_gk2Ydlzh, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_Uwuuf8Bq, VOf(Bf2));
    __hv_line_f(&sLine_ILWAHCbC, VOf(Bf6));
    __hv_line_f(&sLine_gjCMOH9Y, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_yrOxRkzU, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_K3REoeJ9, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_iIktE68K, VOf(Bf8));
    __hv_line_f(&sLine_KM94CC1R, VOf(Bf2));
    __hv_line_f(&sLine_CCFqq9Pj, VOf(Bf1));
    __hv_line_f(&sLine_omhcwdIG, VOf(Bf7));
    __hv_line_f(&sLine_epC4gVaG, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_BaZCjvEX, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_2q0jgeJQ, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
